@@ -10,21 +10,21 @@ our $alien_key = 'mac_3_0_5_uni_nc_0';
 {
     my $VAR1;
     $Wx::dlls = $VAR1 = {
-          'ribbon' => 'libwx_osx_cocoau_ribbon-3.0.dylib',
-          'gl' => 'libwx_osx_cocoau_gl-3.0.dylib',
-          'richtext' => 'libwx_osx_cocoau_richtext-3.0.dylib',
-          'xml' => 'libwx_baseu_xml-3.0.dylib',
-          'qa' => 'libwx_osx_cocoau_qa-3.0.dylib',
-          'stc' => 'libwx_osx_cocoau_stc-3.0.dylib',
-          'aui' => 'libwx_osx_cocoau_aui-3.0.dylib',
           'core' => 'libwx_osx_cocoau_core-3.0.dylib',
-          'media' => 'libwx_osx_cocoau_media-3.0.dylib',
-          'xrc' => 'libwx_osx_cocoau_xrc-3.0.dylib',
-          'net' => 'libwx_baseu_net-3.0.dylib',
           'html' => 'libwx_osx_cocoau_html-3.0.dylib',
+          'xml' => 'libwx_baseu_xml-3.0.dylib',
+          'ribbon' => 'libwx_osx_cocoau_ribbon-3.0.dylib',
+          'media' => 'libwx_osx_cocoau_media-3.0.dylib',
           'base' => 'libwx_baseu-3.0.dylib',
+          'aui' => 'libwx_osx_cocoau_aui-3.0.dylib',
+          'gl' => 'libwx_osx_cocoau_gl-3.0.dylib',
+          'qa' => 'libwx_osx_cocoau_qa-3.0.dylib',
+          'xrc' => 'libwx_osx_cocoau_xrc-3.0.dylib',
+          'propgrid' => 'libwx_osx_cocoau_propgrid-3.0.dylib',
+          'net' => 'libwx_baseu_net-3.0.dylib',
           'adv' => 'libwx_osx_cocoau_adv-3.0.dylib',
-          'propgrid' => 'libwx_osx_cocoau_propgrid-3.0.dylib'
+          'stc' => 'libwx_osx_cocoau_stc-3.0.dylib',
+          'richtext' => 'libwx_osx_cocoau_richtext-3.0.dylib'
         };
 ;
 }
